@@ -7,3 +7,7 @@ GL_FUNC (PFNGLBLENDFUNCSEPARATEEXTPROC, BlendFuncSeparateEXT)
 GL_FUNC (PFNGLCONVOLUTIONPARAMETERFEXTPROC, ConvolutionParameterf)
 GL_FUNC (PFNGLCONVOLUTIONFILTER2DEXTPROC, ConvolutionFilter2D)
 GL_FUNC (PFNGLSEPARABLEFILTER2DEXTPROC, SeparableFilter2D)
+GL_FUNC (PFNGLMULTITEXCOORD2FARBPROC, MultiTexCoord2f)
+GL_FUNC (PFNGLACTIVETEXTUREARBPROC, ActiveTexture)
+GL_FUNC (PFNGLMULTITEXCOORD2FARBPROC, MultiTexCoord2fARB)
+GL_FUNC (PFNGLACTIVETEXTUREARBPROC, ActiveTextureARB)
